@@ -311,7 +311,7 @@ build_object (GoaProvider         *provider,
       g_signal_connect (account,
                         "notify::maps-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
-                        "MapsEnabled");
+                        (gpointer) "MapsEnabled");
     }
 
   ret = TRUE;
