@@ -38,9 +38,6 @@ void             goa_object_skeleton_attach_contacts       (GoaObjectSkeleton *o
                                                             gboolean           contacts_enabled,
                                                             gboolean           accept_ssl_errors);
 
-void             goa_object_skeleton_attach_documents      (GoaObjectSkeleton *object,
-                                                            gboolean           documents_enabled);
-
 void             goa_object_skeleton_attach_files          (GoaObjectSkeleton *object,
                                                             const gchar       *uri,
                                                             gboolean           files_enabled,
