@@ -30,7 +30,6 @@
 #include "goaflickrprovider.h"
 #include "goafoursquareprovider.h"
 #include "goawindowsliveprovider.h"
-#include "goapocketprovider.h"
 #include "goamediaserverprovider.h"
 #include "goalastfmprovider.h"
 
@@ -951,9 +950,6 @@ static struct
 #ifdef GOA_FLICKR_ENABLED
   { GOA_FLICKR_NAME, goa_flickr_provider_get_type },
 #endif
-#ifdef GOA_POCKET_ENABLED
-  { GOA_POCKET_NAME, goa_pocket_provider_get_type },
-#endif
 #ifdef GOA_FOURSQUARE_ENABLED
   { GOA_FOURSQUARE_NAME, goa_foursquare_provider_get_type },
 #endif
